import React from "react";
import { StaticImage, IGatsbyImageData, GatsbyImage, getImage } from "gatsby-plugin-image";

interface Props {
  image?: string | IGatsbyImageData;
}


const CardImage = (props: Props) => {
  const {
    image
  } = props;
  
  const imageNoAvailable = (
    <StaticImage 
      src='../../../images/no-image-available.jpg'
      alt="no-image-available"
      className="h-full w-full object-cover"
    />
  )

  if (! image || typeof image == 'undefined') {
    return (
      <>
        {imageNoAvailable}
      </>
    );
  }

  if (typeof image == 'string') {
    return (
      <>
        <img 
          src={image} 
          alt={image} 
          className="h-full w-full object-cover"
        />
      </>
    )
  }

  const img = getImage(image) ;
  if (typeof img == 'undefined') {
    return (
      <>
        {imageNoAvailable}
      </>
    )
  }

  return (
    <>
      <GatsbyImage image={img} alt="gatsby-image" className="h-full w-full object-cover"/>
    </>
  )
};


export default CardImage;